﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using Telerik.Web.UI.Gantt;


public partial class Gantt : System.Web.UI.Page
{
    private const string TasksKey = "Telerik.GanttSample.Tasks";
    private const string DependenciesKey = "Telerik.GanttSample.Dependencies";

    private List<Task> Tasks
    {
        get
        {
            List<Task> sessionTasks = Session[TasksKey] as List<Task>;

            if (sessionTasks == null)
            {
                sessionTasks = new List<Task>();

                sessionTasks.Add(new Task
                {
                    ID = 1,
                    Title = "First Task",
                    Start = new DateTime(2014, 8, 5, 9, 10, 0),
                    End = new DateTime(2014, 8, 5, 12, 40, 0),
                    OrderID = 0
                });

                Session[TasksKey] = sessionTasks;
            }

            return sessionTasks;
        }
    }

    public List<Dependency> Dependencies
    {
        get
        {
            List<Dependency> sessionDependencies = Session[DependenciesKey] as List<Dependency>;

            if (sessionDependencies == null)
            {
                sessionDependencies = new List<Dependency>();

                Session[DependenciesKey] = sessionDependencies;
            }

            return sessionDependencies;
        }
    }

    protected void Page_Load(object sender, EventArgs e)
    {
        RadGantt1.DataSource = Tasks;
        RadGantt1.DependenciesDataSource = Dependencies;
    }

    protected void RadGantt1_TaskDelete(object sender, TaskEventArgs e)
    {
        foreach (Task task in e.Tasks)
        {
            var original = GetByID((int)task.ID);

            Tasks.Remove(original);
        }
    }

    protected void RadGantt1_TaskUpdate(object sender, TaskEventArgs e)
    {
        foreach (Task task in e.Tasks)
        {
            var original = GetByID((int)task.ID);

            original.Start = task.Start;
            original.End = task.End;
            original.Title = task.Title;
            original.PercentComplete = task.PercentComplete;
            original.OrderID = task.OrderID;
            original.Summary = task.Summary;
            original.ParentID = task.ParentID;
        }
    }

    protected void RadGantt1_TaskInsert(object sender, TaskEventArgs e)
    {
        foreach (Task task in e.Tasks)
        {
            task.ID = NextID();

            Tasks.Add(task);
        }
    }

    private Task GetByID(int id)
    {
        return Tasks.Find((task) => (int)task.ID == id);
    }

    private int NextID()
    {
        var nextID = 0;

        foreach (ITask task in Tasks)
        {
            if ((int)task.ID > 0)
            {
                nextID = (int)task.ID;
            }
        }

        return ++nextID;
    }

    protected void RadGantt1_DependencyInsert(object sender, DependencyEventArgs e)
    {
        foreach (Dependency dependency in e.Dependencies)
        {
            dependency.ID = NextDependencyID();

            Dependencies.Add(dependency);
        }
    }

    protected void RadGantt1_DependencyDelete(object sender, DependencyEventArgs e)
    {
        foreach (Dependency dependency in e.Dependencies)
        {
            var original = GetDependencyByID((int)dependency.ID);

            Dependencies.Remove(original);
        }
    }

    private Dependency GetDependencyByID(int id)
    {
        return Dependencies.Find((dependency) => (int)dependency.ID == id);
    }

    private int NextDependencyID()
    {
        var nextID = 0;

        foreach (IDependency dependency in Dependencies)
        {
            if ((int)dependency.ID > 0)
            {
                nextID = (int)dependency.ID;
            }
        }

        return ++nextID;
    }
}